summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/drivers/superqix.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/drivers/superqix.cpp')
-rw-r--r--src/mame/drivers/superqix.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/mame/drivers/superqix.cpp b/src/mame/drivers/superqix.cpp
index 311f123d3ce..fee953cae2e 100644
--- a/src/mame/drivers/superqix.cpp
+++ b/src/mame/drivers/superqix.cpp
@@ -920,7 +920,7 @@ void superqix_state_base::machine_init_common()
// superqix specific stuff, TODO: should be moved to superqix_state below
save_item(NAME(m_gfxbank));
save_item(NAME(m_show_bitmap));
// the following are saved in superqix_state::video_start_superqix:
//save_item(NAME(*m_fg_bitmap[0]));
//save_item(NAME(*m_fg_bitmap[1]));
}
@@ -949,7 +949,7 @@ void hotsmash_state::machine_init_common()
save_item(NAME(m_dial_sign));
}
-void superqix_state::machine_reset_superqix()
+MACHINE_RESET_MEMBER(superqix_state, superqix)
{
if (m_mcu.found()) // mcu sets only
{
@@ -962,7 +962,7 @@ void superqix_state::machine_reset_superqix()
}
}
-void superqix_state::machine_start_superqix()
+MACHINE_START_MEMBER(superqix_state, superqix)
{
/* configure the banks */
membank("bank1")->configure_entries(0, 4, memregion("maincpu")->base() + 0x10000, 0x4000);
@@ -970,7 +970,7 @@ void superqix_state::machine_start_superqix()
machine_init_common();
}
-void hotsmash_state::machine_start_pbillian()
+MACHINE_START_MEMBER(hotsmash_state, pbillian)
{
/* configure the banks */
membank("bank1")->configure_entries(0, 2, memregion("maincpu")->base() + 0x10000, 0x4000);
@@ -1362,7 +1362,7 @@ MACHINE_CONFIG_START(hotsmash_state::pbillian)
MCFG_M68705_PORTC_W_CB(WRITE8(*this, hotsmash_state, hotsmash_68705_portC_w))
//MCFG_QUANTUM_PERFECT_CPU("maincpu")
- set_machine_start_cb(config, driver_callback_delegate(&machine_start_pbillian, this));
+ MCFG_MACHINE_START_OVERRIDE(hotsmash_state, pbillian)
/* video hardware */
MCFG_SCREEN_ADD("screen", RASTER)
@@ -1378,7 +1378,7 @@ MACHINE_CONFIG_START(hotsmash_state::pbillian)
MCFG_PALETTE_ADD("palette", 512)
MCFG_PALETTE_FORMAT_CLASS(1, superqix_state, BBGGRRII)
- set_video_start_cb(config, driver_callback_delegate(&video_start_pbillian, this));
+ MCFG_VIDEO_START_OVERRIDE(hotsmash_state, pbillian)
SPEAKER(config, "mono").front_center();
@@ -1408,7 +1408,7 @@ MACHINE_CONFIG_START(superqix_state::sqix)
MCFG_MCS51_PORT_P3_IN_CB(READ8(*this, superqix_state, mcu_port3_r))
MCFG_MCS51_PORT_P3_OUT_CB(WRITE8(*this, superqix_state, mcu_port3_w))
- set_machine_start_cb(config, driver_callback_delegate(&machine_start_superqix, this));
+ MCFG_MACHINE_START_OVERRIDE(superqix_state,superqix)
/* video hardware */
MCFG_SCREEN_ADD("screen", RASTER)
@@ -1423,7 +1423,7 @@ MACHINE_CONFIG_START(superqix_state::sqix)
MCFG_PALETTE_ADD("palette", 256)
MCFG_PALETTE_FORMAT_CLASS(1, superqix_state, BBGGRRII)
- set_video_start_cb(config, driver_callback_delegate(&video_start_superqix, this));
+ MCFG_VIDEO_START_OVERRIDE(superqix_state,superqix)
/* sound hardware */
SPEAKER(config, "mono").front_center();
@@ -1461,7 +1461,7 @@ MACHINE_CONFIG_START(superqix_state::sqix_nomcu)
MCFG_DEVICE_IO_MAP(sqix_port_map)
MCFG_DEVICE_PERIODIC_INT_DRIVER(superqix_state, sqix_timer_irq, 4*60) /* ??? */
- set_machine_start_cb(config, driver_callback_delegate(&machine_start_superqix, this));
+ MCFG_MACHINE_START_OVERRIDE(superqix_state,superqix)
/* video hardware */
MCFG_SCREEN_ADD("screen", RASTER)
@@ -1476,7 +1476,7 @@ MACHINE_CONFIG_START(superqix_state::sqix_nomcu)
MCFG_PALETTE_ADD("palette", 256)
MCFG_PALETTE_FORMAT_CLASS(1, superqix_state, BBGGRRII)
- set_video_start_cb(config, driver_callback_delegate(&video_start_superqix, this));
+ MCFG_VIDEO_START_OVERRIDE(superqix_state,superqix)
/* sound hardware */
SPEAKER(config, "mono").front_center();
@@ -920,7 +920,7 @@ void superqix_state_base::machine_init_common()
save_item(NAME(m_gfxbank));
save_item(NAME(m_show_bitmap));
- // the following are saved in superqix_state::video_start_superqix:
+ // the following are saved in VIDEO_START_MEMBER(superqix_state,superqix):
//save_item(NAME(*m_fg_bitmap[0]));
//save_item(NAME(*m_fg_bitmap[1]));